uniform mediump float threshold;
uniform mediump float lowThreshold;
uniform mediump float brightness;
uniform lowp vec3 tint;
uniform mediump float maskedOpacity;

varying mediump vec2 vTex;
uniform lowp sampler2D samplerFront;
uniform mediump vec2 srcStart;
uniform mediump vec2 srcEnd;
uniform mediump vec2 destStart;
uniform mediump vec2 destEnd;
uniform lowp sampler2D samplerBack;

#define W vec3(.2126, .7152, .0722)

void main(void)
{
    //sample front
    lowp vec4 front = texture2D(samplerFront, vTex);

    //sample back
    lowp vec4 back = texture2D(samplerBack, mix(destStart, destEnd, (vTex - srcStart) / (srcEnd - srcStart)));

    //calculate luminance mask
    mediump float mask = smoothstep(threshold - lowThreshold, threshold , dot(back.rgb, W));

    //mask pixels
    lowp vec4 color = (back + brightness - 1.) * mask * front.a;
   
    //tint
    color *= vec4(tint, 1.);

    //output color
    gl_FragColor = vec4(color.rgb, color.a + maskedOpacity * front.a);
}